/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState } from 'react';
//imports material ui componets
import Card from "@material-ui/core/Card";
import CardContent from "@material-ui/core/CardContent";
import CardAction from '@material-ui/core/CardActions';
import { Typography, TextField, Button, Grid } from '@material-ui/core';
import CircularProgress from '@material-ui/core/CircularProgress';
import AddRoundedIcon from '@material-ui/icons/AddRounded';
import ListRoundedIcon from '@material-ui/icons/ListRounded';
//imports local files
import SnackBar from '../../../../Components/SnackbarComponent';
import { postRequest } from '../../../../Components/HelperFunctions/getAxiosConfig'
//router
import { Link } from 'react-router-dom';

const CreateLanguage = (props) => {

    const [name, setName] = useState('Nova linguagem');
    const [code, setCode] = useState('');

    const [isLoading, setIsLoading] = useState(false)

    // Handle error in name
    const [errorInName, setErrorInName] = useState({
        error: false,
        message: '',
    })

    // Handle error in Country 
    const [errorInCode, setErrorInCode] = useState({
        error: false,
        message: '',
    })

    const [snackInfo, setSnackInfo] = useState({
        message: '',
        icon: '',
        open: false,
        color: '',
    })

    const NameHandler = (e) => {
        setName(e.target.value)
        if (errorInName.error) {
            setErrorInName({
                error: false,
                message: ''
            })
        }
    }

    const CodeHandler = (e) => {
        if (errorInCode.error) {
            setErrorInCode({
                error: false,
                message: ''
            })
        }
        setCode(e.target.value)
    }

    // Handle snack infos
    const HandleSnack = (message, state, icon, color) => {
        setSnackInfo({
            message: message,
            icon: icon,
            open: state,
            color: color
        })
    }

    //Handle submit 
    async function onSubmit() {
        setIsLoading(true)
        const api = '/languages'
        const body = {
            "language": {
                'name': name,
                'code': code,
            }
        }
        postRequest(
            api,
            body,
            (data) => {
                if (data.id)
                    HandleSnack('A linguagem foi criada com sucesso', true, 'success', '#228B22')
                else {
                    if (data.errors) {
                        HandleSnack(`${data.errors[0]}`, true, 'warning', '#FA8072')
                    }
                    else {
                        if (data.name) {
                            let nameError = "";
                            data.name.map((msg) => (
                                nameError = nameError + msg + " e "
                            ))
                            setErrorInName({
                                error: true,
                                message: nameError
                            })
                        }
                        if (data.code) {
                            let codeError = "";
                            data.code.map((msg) => (
                                codeError = codeError + msg + " e "
                            ))
                            setErrorInCode({
                                error: true,
                                message: codeError
                            })
                        }
                        HandleSnack('Você precisa preencher algumas informações obrigatórias', true, 'warning', '#FFC125')
                    }
                }
                setIsLoading(false)
            },
            (error) => {
                HandleSnack('Ocorreu algum erro', true, 'warning', '#FA8072')
                setIsLoading(false)
            }
        )
    }

    // Fields
    const fields = [
        {
            label: 'Nome',
            value: name,
            required: true,
            error: errorInName.error,
            errorMessage: errorInName.message,
            onChange: (event) => NameHandler(event)
        },
        {
            label: 'Código',
            value: code,
            required: true,
            error: errorInCode.error,
            errorMessage: errorInCode.message,
            onChange: (event) => CodeHandler(event)
        }
    ]

    return (
        <Card>
            <SnackBar
                severity={snackInfo.icon}
                text={snackInfo.message}
                snackbarOpen={snackInfo.open}
                color={snackInfo.color}
                handleClose={() => setSnackInfo({
                    message: '',
                    icon: '',
                    open: false,
                    color: ''
                })}
            />
            <CardContent>
                <Grid container direction='row' justify='space-between' alignItems="center" alignContent="center" xs={12}>
                    <Grid item>
                        <Typography variant='h4'>
                            {name}
                        </Typography>
                    </Grid>
                    <Grid item>
                        <Link to={'/admin/languages'} style={{ textDecoration: 'none' }}>
                            <Button
                                onClick={props.BackToList}
                                startIcon={<ListRoundedIcon />}
                                variant='outlined'
                                color='primary'
                            >
                                Listar
                        </Button>
                        </Link>
                    </Grid>
                </Grid>

                <div style={{ height: '1em' }}></div>

                <form style={{ display: 'flex', flexDirection: 'column' }}>
                    {fields.map((field, index) => (
                        <TextField
                            key={index}
                            required={field.required}
                            error={field.error}
                            helperText={field.error ? field.errorMessage : ''}
                            style={{ width: '250px', marginBottom: '1em' }}
                            label={field.label}
                            value={field.value}
                            onChange={field.onChange}
                            type="search"
                            multiline={true}
                        />
                    ))}
                </form>
            </CardContent>
            <CardAction>
                <Button
                    onClick={() => {
                        onSubmit();
                    }}
                    variant="contained"
                    color="primary"
                    disabled={isLoading}
                    startIcon={isLoading ? null : <AddRoundedIcon />}
                >
                    {
                        isLoading ? <CircularProgress size={24} /> : 'Adicionar'
                    }
                </Button>
            </CardAction>
        </Card>
    )
}

export default CreateLanguage;