/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState } from "react";
import { Button } from '@material-ui/core';
//import FacebookLogin from 'react-facebook-login';
import CloseIcon from '@material-ui/icons/Close';
import styled from 'styled-components'
import { device } from './device.js'
import FormInput from "./FormInput.js"
import { StyledCloseModalButton, DialogContentDiv, DialogHeaderStyled, SocialConnectDiv, H3Div } from './LoginContainerFunction.js'
import { apiUrl } from '../env.js'
import { GoogleLoginButton } from './LoginContainerFunction'
import ValidateUserInput from './HelperFunctions/FormValidationFunction.js'
import GoogleLogo from "../img/logo_google.svg"
import ReCaptcha from 'react-recaptcha'

async function handleGoogleAttempt() {
    console.log("handleGoogleAttempt")
    let request_url = (
        `${apiUrl}/omniauth/google_oauth2?auth_origin_url=` + window.location.href + '&omniauth_window_type=sameWindow&resource_class=User'
    )
    window.location.replace(request_url)
}
export default function SignUpContainer(props) {
    const [unavailableButton, setButtonAvailability] = useState(true);

    const [formNome, setNome] = useState(
        {
            key: false,
            value: "",
        }
    )

    const [formEmail, setEmail] = useState(
        {
            key: false,
            value: "",
        }
    )

    const [formSenha, setSenha] = useState(
        {
            key: false,
            value: ""
        }
    )

    const [formConfirmation, setConfirmation] = useState(
        {
            key: false,
            value: ""
        }
    )

    const handleChange = (e, type, confirmation) => {
        const userInput = e.target.value
        const flag = ValidateUserInput(type, userInput, confirmation)

        if (type === 'username') {
            setNome({
                ...formNome,
                key: flag,
                value: userInput
            })
            console.log(formNome)
        }
        else if (type === 'email') {
            setEmail({
                ...formEmail,
                key: flag,
                value: userInput
            })
            console.log(formEmail)
        }
        else if (type === 'password') {
            setSenha({
                ...formSenha,
                key: flag,
                value: userInput
            })
            console.log(formSenha)
        }
        else if (type === 'confirmation') {
            setConfirmation({
                ...formConfirmation,
                key: flag,
                value: userInput
            })
            console.log(formConfirmation)
        }
    }

    const limpaCamposForm = () => {
        setNome({
            ...formNome,
            key: false,
            value: ''
        })

        setEmail({
            ...formEmail,
            key: false,
            value: ''
        });

        setSenha({
            ...formSenha,
            key: false,
            value: ''
        })

        setConfirmation({
            ...formConfirmation,
            key: false,
            value: ''
        })
    }

    const switchModal = (e) => {
        e.preventDefault()
        props.handleClose()
        props.openLogin()
    };

    const onSubmit = (e) => {
        e.preventDefault();
        const newLogin = { name: formNome.value, email: formEmail.value, password: formSenha.value, senha: formConfirmation.value }

        if (!(formNome.key || formEmail.key || formSenha.key || formConfirmation.key)) {
            props.handleLoginInfo(newLogin)
            limpaCamposForm()
        }
    }

    function captchaVerified(response) {
        if (response) {
            setButtonAvailability(false)
        }
    }

    return (
        <ContainerStyled contrast={props.contrast}>
            <DialogHeaderStyled>
                <span style={{ width: "32px" }} />
                <H2Styled contrast={props.contrast}> Cadastrar-se
                </H2Styled>
                <StyledCloseModalButton contrast={props.contrast} onClick={props.handleClose} >
                    <CloseIcon className="icon" />
                </StyledCloseModalButton>
            </DialogHeaderStyled>

            <DialogContentDiv>
                <SocialConnectDiv>
                    <GoogleLoginButton contrast={props.contrast} onClick={handleGoogleAttempt}>
                        <img src={GoogleLogo} alt="google-logo" className="google-logo" />
                        <span>Usando o Google</span>
                    </GoogleLoginButton>
                </SocialConnectDiv>

                <H3Div>
                    <H3Styled contrast={props.contrast}>
                        <RightSideStrikedH3 contrast={props.contrast} />
                        <span style={{ verticalAlign: "middle" }}>ou</span>
                        <LeftSideStrikedH3 contrast={props.contrast} />
                    </H3Styled>
                </H3Div>

                <form onSubmit={onSubmit}>
                    <FormInput
                        contrast={props.contrast}
                        inputType={"text"}
                        name={"name"}
                        value={formNome.value}
                        placeholder={"Nome Completo"}
                        handleChange={e => handleChange(e, 'username')}
                        required={true}
                        error={formNome.key}
                    />
                    <br />
                    <FormInput
                        contrast={props.contrast}
                        inputType={"text"}
                        name={"email"}
                        value={formEmail.value}
                        placeholder={"E-mail"}
                        handleChange={e => handleChange(e, 'email')}
                        required={true}
                        error={formEmail.key}
                        help={formEmail.key ? (formEmail.value.length === 0 ? "Faltou preencher seu e-mail." : <span>Insira um endereço de e-mail válido.<br />Por exemplo: seunome@gmail.com, seunome@hotmail.com</span>) : ""}
                    />
                    <br />
                    <FormInput
                        contrast={props.contrast}
                        inputType={"password"}
                        name={"password"}
                        value={formSenha.value}
                        placeholder={"Senha"}
                        handleChange={e => handleChange(e, 'password')}
                        required={true}
                        error={formSenha.key}
                        help={formSenha.key ? (formSenha.value.length === 0 ? "Faltou digitar sua senha." : "A senha precisa ter no mínimo 8 caracteres.") : ""}
                    />
                    <br />
                    <FormInput
                        contrast={props.contrast}
                        inputType={"password"}
                        name={"confirmation"}
                        value={formConfirmation.value}
                        placeholder={"Confirme a Senha"}
                        handleChange={e => handleChange(e, 'confirmation', formSenha.value)}
                        required={true}
                        error={formConfirmation.key}
                        help={formConfirmation.key ? (formConfirmation.value.length === 0 ? "Faltou digitar sua senha." : (formConfirmation.value !== formSenha.value ? "As senhas precisam ser iguais" : "A senha precisa ter no mínimo 8 caracteres.")) : ""}
                    />
                    <br />
                    <div style={{ margin: "0 auto", width: "304px" }}>
                        {
                            //<ReCaptcha sitekey={process.env.REACT_APP_SITE_KEY} verifyCallback={captchaVerified} /> //when key set in env
                            <ReCaptcha sitekey="6LfxuKUUAAAAAIzYpCzEtJyeE8QRjBYa44dvHlTX" verifyCallback={captchaVerified} /> //use this one on production
                            //<ReCaptcha sitekey="6LeIxAcTAAAAAJcZVRqyHh71UMIEGNQ_MXjiZKhI" verifyCallback={captchaVerified}/> //test key, from google, do not use this one on production
                        }
                    </div>
                    <ConfirmContainerStyled>
                        {
                            !unavailableButton &&
                            <StyledSignUpButton contrast={props.contrast} type="submit" variant="contained" disabled={unavailableButton}
                                style={unavailableButton ? { backgroundColor: "#e9e9e9" } : props.contrast === "" ? { backgroundColor: "#00bcd4" } : { backgroundColor: "black", color: "yellow", textDecoration: "underline" }}
                            >
                                <span
                                    style={props.contrast === "" ? {
                                        paddingLeft: "16px", paddingRight: "16px", borderRadius: "3px", boxSizing: "border-box",
                                        fontFamily: "Roboto, sans serif", fontWeight: "500", color: "#fff"
                                    } : {
                                            paddingLeft: "16px", paddingRight: "16px", borderRadius: "3px", boxSizing: "border-box",
                                            fontFamily: "Roboto, sans serif", fontWeight: "500", color: "yellow"
                                        }}
                                >
                                    CADASTRAR
                            </span>
                            </StyledSignUpButton>
                        }
                    </ConfirmContainerStyled>
                </form>

                <TermosDeUsoStyled contrast={props.contrast}>
                    <p>Ao se cadastrar, você está aceitando os Termos de Uso e de Política
                    de Privacidade. <a href="/termos">Ler Termos</a>.</p>
                </TermosDeUsoStyled>

                <DialogFooterStyled>
                    <span style={props.contrast === "" ? { textAlign: "center", fontSize: "14px" } : { textAlign: "center", fontSize: "14px", color: "white" }}>Já possui cadastro? <StyledAnchor contrast={props.contrast} href="" onClick={e => switchModal(e)}>ENTRAR</StyledAnchor></span>
                </DialogFooterStyled>
            </DialogContentDiv>
        </ContainerStyled>
    )
}

const ContainerStyled = styled.div`
    box-sizing : border-box;
    background: ${props => props.contrast === "" ? "white" : "black"};
    max-width : none;
    align : center;
    display : flex;
    flex-direction : column;
    min-width : 450px;
    border: 1px solid ${props => props.contrast === "" ? "#666" : "white"};
    overflow-y: scroll;

    max-height : 90%;
    position : relative;
    padding : 10px;
    @media ${device.mobileM} {
        width : 100%;
        min-width : unset;
        height : 90%;
        min-width : unset !important;

    }
`

const DialogFooterStyled = styled.div`
    box-sizing : border-box;
    font-family : 'Roboto', sans serif;
    margin : 20px -20px;
    padding-top : 20px;
    border-top : 1px #e5e5e5 solid;
    justify-content : center;
    text-align : center;
    line-height : 1.42857143
`

const TermosDeUsoStyled = styled.div`
    font-family: 'Roboto', sans serif, 'Helvetica Neue', Helvetica, Arial, sans-serif;
    color: ${props => props.contrast === "" ? "#666" : "white"};
    font-size : 13px;
    margin : 0 0 10px;
    max-width : 350px;
    margin-top : 10px;
    text-align : start;
    a{
        color: ${props => props.contrast === "" ? "#00bcd4" : "yellow"};
        text-decoration: ${props => props.contrast === "" ? "none" : "underline"}
    }
`

const H2Styled = styled.h2`
    align-self : center;
    color: ${props => props.contrast === "" ? "#666" : "white"};
    font-size : 26px;
    font-weight : lighter;
    justify-content: space-between;
    font-family: 'Roboto', sans serif, 'Helvetica Neue', Helvetica, Arial, sans-serif !important;
    text-align: center;
    letter-spacing: .005em;
`

const H3Styled = styled.h3`
    overflow : hidden;
    text-align : center;
    font-size : 14px;
    color: ${props => props.contrast === "" ? "#666" : "white"};
    margin : 10px 0;
`
const RightSideStrikedH3 = styled.div`
    display :  inline-block;
    border-bottom: ${props => props.contrast === "" ? "1px dotted #666" : "1px dotted white"};
    vertical-align :  middle;
    font-weight : 500;
    margin-right : 5px;
    width : 44%;
`

const LeftSideStrikedH3 = styled.div`
    display :  inline-block;
    border-bottom: ${props => props.contrast === "" ? "1px dotted #666" : "1px dotted white"};
    vertical-align :  middle;
    font-weight : 500;
    margin-left : 5px;
    width : 44%;
`

const StyledAnchor = styled.a`
    color: ${props => props.contrast === "" ? "#00bcd4" : "yellow"};
    text-decoration: ${props => props.contrast === "" ? "none" : "underline"}
`
//const StyledCloseModalButton = styled(Button)`
//    display : inline-block;
//    position : relative;
//    float : right !important;
//    margin-right : -8px;
//    background : transparent;
//    min-width: 0 !important;
//    width : 40px;
//`

const ConfirmContainerStyled = styled.div`
    display :  flex;
    margin-top : 10px;
    align-items : center;
    justify-content : center;
    box-sizing : border-box;
    font-size : 13px;
`

const StyledSignUpButton = styled(Button)`
    box-shadow : none !important;
    outline: none !important;
    border: ${props => props.contrast === "" ? "0 !important" : "1px solid white !important"};
    overflow : hidden !important;
    width : 50% !important;
    display : inline-block !important;
    font-family : 'Roboto', sans serif !important;
    font-size: 14px !important;
    height : 36px !important;
    align-items : center !important;
    border-radius: 3px !important;
    align-self : 50% !important;
    :hover {
        background-color: ${props => props.contrast === "" ? "#00acc1 !important" : "rgba(255,255,0,0.24) !important"};
    }
`
