/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, memo, useEffect, useRef } from 'react'
import FormControl from '@material-ui/core/FormControl';
import { StyledTextField, StyledFormLabel } from '../StyledComponents.js'
import styled from 'styled-components';
import DeleteIcon from '@material-ui/icons/Delete';

import { makeStyles } from "@material-ui/styles";
import { Chip } from '@material-ui/core';

const useStyles = makeStyles(theme => ({
    darkTextField: {
        maxWidth: "100%",
        fontSize: "15px",
        fontWeight: "lighter",
        color: "white",
        width: "100%",
    },
    lightTextField: {
        maxWidth: "100%",
        fontSize: "15px",
        fontWeight: "lighter",
        color: "black",
        width: "100%",
    }
}));

function Keywords(props) {
    const classes = useStyles();
    const [keywords, setKeywords] = useState(props.initialValue ? props.initialValue : [])
    const handleSetKeywords = (newKeyword) => { setKeywords(newKeyword) }
    const deleteKeyword = (keywordToDelete) => {
        handleSetKeywords(keywords.filter((keyword) => keyword !== keywordToDelete))
    }

    const resettingRef = useRef(false);

    useEffect(() => {
        if (resettingRef.current) { //used to ensure that keywords are updated before sending (after a delete)
            resettingRef.current = false;
            props.onBlurCallback("tags", keywords, props.draftID);
        }
    }, [keywords])

    const [keywordsBuffer, setKeywordsBuffer] = useState('')

    const handleKeywords = (event) => {
        let userInput = event.target.value;

        if (userInput.indexOf(',') !== -1) {
            if (userInput.length > 1) {
                handleSetKeywords([...keywords, userInput.split(',')[0]])
            }
            setKeywordsBuffer('')
        }
        else {
            setKeywordsBuffer(userInput)
        }
    }


    return (
        <React.Fragment>
            <FormControl required={true} style={{ width: "100%" }}>
                <StyledFormLabel contrast={props.contrast} component="legend" style={{ fontSize: "14px", marginBottom: "10px" }}>
                    <b>Palavras-chave para buscar o Recurso</b>
                    <span style={props.contrast === "" ? { color: "#a5a5a5", paddingLeft: "10px" } : { color: "white", paddingLeft: "10px" }}>
                        (Use vírgula ou enter para separar as palavras-chave)</span>
                </StyledFormLabel>
                <StyledTextField
                    contrast={props.contrast}
                    variant='outlined'
                    InputProps={props.contrast === "" ? { className: classes.lightTextField } : { className: classes.darkTextField }}
                    id={"text-form"}
                    placeholder={"Ex: Biomas, Geografia, ..."}
                    type={"text"}
                    value={keywordsBuffer}
                    onChange={handleKeywords}
                    onKeyDown={(event) => {
                        if (event.keyCode === 13) {
                            handleSetKeywords([...keywords, keywordsBuffer])
                            setKeywordsBuffer('')
                        }
                    }
                    }
                    fullWidth
                    onBlur={() => { props.onBlurCallback("tags", keywords, props.draftID) }}
                />
            </FormControl>
            <SizedBox />
            {
                keywords.length !== 0 &&
                keywords.map((keyword) =>
                    <Chip style={props.contrast === "" ? { margin: "0.3em 0.5em" } : { border: "1px solid white", backgroundColor: "black", margin: "0.3em 0.5em", color: "white" }} label={keyword} key={keyword} onDelete={() => deleteKeyword(keyword)} deleteIcon={<DeleteIcon style={props.contrast === "" ? {} : { color: "white" }} />} />
                )
            }
        </React.Fragment>
    )
}

const SizedBox = styled.div`
    height: 2em;
`

export default memo(Keywords)
