/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useContext } from "react";
import { Col, Row, Container } from "react-grid-system";
import { Carousel } from "react-responsive-carousel";
import MaterialCard from "../Components/MaterialCard";
import colecoes_obj from "../Components/FormationMaterialsResources/formationMaterials";
import ExpandedMaterial from "../Components/ExpandedMaterials";
import styled from "styled-components";
import Breadcrumbs from "@material-ui/core/Breadcrumbs";
import { Link } from "react-router-dom";
import { Store } from '../Store';
const MateriaPage = () => {
  const materials = colecoes_obj();
  const { state } = useContext(Store);
  const [currMaterial, setCurrMaterial] = useState({
    open: false,
    material: {},
  });

  const HandleExpandMaterial = (id) => {
    if (id !== currMaterial.material.id)
      setCurrMaterial({
        open: true,
        material: { ...materials[id] },
      });
    else
      setCurrMaterial({
        open: false,
        material: {},
      });
  };

  return (
    <MainPage contrast={state.contrast}>
      <link href="https://fonts.googleapis.com/css?family=Kalam|Pompiere|Roboto&display=swap" rel="stylesheet" />
      <BreadCrumbsDiv>
        <StyledBreadCrumbs contrast={state.contrast}>
          <Link to="/">Página Inicial</Link>
          <span>Materias de Formação</span>
        </StyledBreadCrumbs>
      </BreadCrumbsDiv>
      <StyledBox contrast={state.contrast}>
        <StyledTitle contrast={state.contrast}>
          Materias de formação
        </StyledTitle>
      </StyledBox>
      <MainContainer contrast={state.contrast}>
        <Container style={{ padding: "20px" }}>
          <Carousel
            style={{ padding: "20px" }}
            showThumbs={false}
            showStatus={false}
          >
            <Row>
              {materials.map((material, index) => {
                return (
                  <Col md={3} key={index}>
                    <MaterialCard
                      contrast={state.contrast}
                      name={material.name}
                      thumb={material.img}
                      score={material.score}
                      modules={material.topics}
                      handleExpand={HandleExpandMaterial}
                      id={index}
                    />
                  </Col>
                );
              })}
            </Row>
          </Carousel>
          {currMaterial.open ? (
            <ExpandedMaterial contrast={state.contrast} material={currMaterial.material} />
          ) : null}
        </Container>
      </MainContainer>
    </MainPage>
  );
};

export default MateriaPage;

const MainPage = styled.div`
    background: ${props => props.contrast === "" ? "" : "black"};
`

const MainContainer = styled.div`
  background: ${props => props.contrast === "" ? "" : "black"};
  margin-left: auto;
  margin-right: auto;
  padding: 0;

  @media screen and (min-width: 768px) {
    width: 750px;
  }
  @media screen and (min-width: 992px) {
    width: 970px;
  }
  @media screen and (min-width: 1200px) {
    width: 1170px;
  }
`

const StyledBreadCrumbs = styled(Breadcrumbs)`
  display: flex;
  justify-content: flex-start;
  max-width: 1170px;
  span {
    color: ${props => props.contrast === "" ? "#a5a5a5" : "white"};
  }
  a {
    color: ${props => props.contrast === "" ? "#00bcd4" : "yellow"};
    text-decoration: ${props => props.contrast === "" ? "none" : "underline"};
  }
`

const BreadCrumbsDiv = styled.div`
  padding: 10px;
  display: flex;
`

const StyledBox = styled.div`
    background: ${props => props.contrast === "" ? "#fff" : "black"};
    box-shadow: 1px 1px 3px rgba(0,0,0,.12), 1px 1px 2px rgba(0,0,0,.24);
    border: ${props => props.contrast === "" ? "0" : "1px solid white"};
    padding: 30px;
    margin-bottom: 30px;
    text-align: center;
`
const StyledTitle = styled.span`
    text-align: center;
    color: ${props => props.contrast === "" ? "#e81f4f" : "white"};
    font-size: 26px;
    font-family: "Roboto", sans-serif;
    font-weight: lighter;
`