/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useContext } from 'react';
import styled from 'styled-components';
import Breadcrumbs from '@material-ui/core/Breadcrumbs';
import Grid from '@material-ui/core/Grid';
import CardEncontrando from '../../Components/HelpCenter/Cards/CardEncontrando';
import CardParticipando from '../../Components/HelpCenter/Cards/CardParticipando';
import CardGerenciando from '../../Components/HelpCenter/Cards/CardGerenciando';
import What from '../../Components/HelpCenter/TabsPlataformaMEC/What';
import Understand from '../../Components/HelpCenter/TabsPlataformaMEC/Understand';
import Which from '../../Components/HelpCenter/TabsPlataformaMEC/Which';
import Types from '../../Components/HelpCenter/TabsPlataformaMEC/Types';
import Software from '../../Components/HelpCenter/TabsPlataformaMEC/Software';
import How from '../../Components/HelpCenter/TabsPlataformaMEC/How';
import { Link } from 'react-router-dom';
import { Store } from '../../Store';

export default function TabPlataformaMEC(props) {
  const { state } = useContext(Store);

  const tabs = [
    'O que é a plataforma MEC?',
    'Como foi construída a Plataforma MEC?',
    'Entendendo as 3 áreas da Plataforma',
    'Quais são os Portais Parceiros?',
    'Tipos de recursos',
    'Softwares específicos',
  ]

  const [tabValue, setTabValue] = useState(
    Number(props.location.state.value) || 0);

  const handleChangeTab = (event, index) => {
    event.preventDefault();
    setTabValue(index);
  }

  return (
    <MainPage contrast={state.contrast}>
      <link href="https://fonts.googleapis.com/css?family=Pompiere|Roboto:300,400&display=swap" rel="stylesheet" />

      <Secao>
        <BreadCrumbsDiv>
          <StyledBreadCrumbs contrast={state.contrast}>
            <Link to="/" >
              Página Inicial
            </Link>
            <Link to="ajuda" >
              Ajuda
            </Link>

            <span>
              Plataforma MEC
            </span>

          </StyledBreadCrumbs>

        </BreadCrumbsDiv>

        <MainGrid container justify='center' spacing={4}>
          <Grid xs={12} md={3} sm={4} item>
            <Menu contrast={state.contrast}>
              <p className="title">
                Plataforma MEC
              </p>
              <div className="sized-box" />

              {
                tabs.map((tab, index) => {
                  return (
                    <TabStyled contrast={state.contrast} active={index === tabValue} name={index} onClick={(event) => handleChangeTab(event, index)} key={new Date().toISOString() + index}>
                      {tab}
                    </TabStyled>
                  )
                })
              }

              <div className="sized-box" />
              <Link to="ajuda">
                <p className="go-back">
                  Voltar ao início
                </p>
              </Link>

              <div className="sized-box" />
              <p className="sub-title">
                Não encontrou o que procurava? Entre em
                <Link to="contato">
                  <span className="go-back"> contato</span>
                </Link>
              </p>
            </Menu>
          </Grid>

          <Grid xs={12} md={9} sm={8} item>
            <Principal>
              {tabValue === 0 && <What contrast={state.contrast} title={tabs[0]} />}
              {tabValue === 1 && <How contrast={state.contrast} title={tabs[1]} />}
              {tabValue === 2 && <Understand contrast={state.contrast} title={tabs[2]} />}
              {tabValue === 3 && <Which contrast={state.contrast} title={tabs[3]} />}
              {tabValue === 4 && <Types contrast={state.contrast} title={tabs[4]} />}
              {tabValue === 5 && <Software contrast={state.contrast} title={tabs[5]} />}
            </Principal>
          </Grid>
        </MainGrid>

        <MainGrid container spacing={4}>
          <Grid xs={12} md={4} item>
            <CardEncontrando contrast={state.contrast} />
          </Grid>

          <Grid item xs={12} md={4} >
            <CardParticipando contrast={state.contrast} />
          </Grid>

          <Grid item xs={12} md={4} >
            <CardGerenciando contrast={state.contrast} />
          </Grid>
        </MainGrid>
      </Secao>
    </MainPage>
  );
}

const StyledBreadCrumbs = styled(Breadcrumbs)`
  display : flex;
    justify-content : flex-start;
    max-width : 1170px;
    a{
        color: ${props => props.contrast === "" ? "#00bcd4" : "yellow"};
        text-decoration: ${props => props.contrast === "" ? "none" : "underline"};
    }
    span {
        color: ${props => props.contrast === "" ? "#a5a5a5" : "white"};
    }
`

const MainPage = styled.div`
  background: ${props => props.contrast === "" ? "#f4f4f4" : "black"};
`

const BreadCrumbsDiv = styled.div`
  display : flex;
`

const MainGrid = styled(Grid)`
  padding: 1.5em 0;
`

const Principal = styled.div`
  
`

const TabStyled = styled.div`
  text-align: center; 
  font-family: 'Roboto', 'sans-serif';
  font-weight: ${props => props.active ? "500" : "lighter"};
  background: ${props => props.active ? props.contrast === "" ? "#e7e4e4" : "rgba(255,255,0,0.24)" : ""};
  padding: 0.5em;
  color: ${props => props.contrast === "" ? "" : "yellow"};
  text-decoration: ${props => props.active ? "none" : props.contrast === "" ? "none" : "underline"};

  :hover{
    background: ${props => props.contrast === "" ? "#e7e4e4" : "rgba(255,255,0,0.24)"};
    cursor: pointer;
    font-weight: 500;
  }
`


const Menu = styled.div`
  box-shadow: 0 1px 3px rgba(0,0,0,.12),0 1px 2px  rgba(0,0,0,.24);
  background: ${props => props.contrast === "" ? "#fff" : "black"};
  border: ${props => props.contrast === "" ? "none" : "1px solid white"};
  color: ${props => props.contrast === "" ? "" : "white"};
  width: 100%;
  padding: 1em 0;

  .sized-box{
    border: 0.5px solid #d4d4d4;
    margin: 1em 0;
  }

  .title{
    padding: 0;
    margin: 0;
    font-weight: 500;
    text-align: center;
    font-family: 'Roboto', 'sans-serif';
  }

  .sub-title{
    padding: 0;
    margin: 0;
    font-weight: lighter;
    text-align: center;
    font-family: 'Roboto', 'sans-serif';
  }

  .go-back{
    padding: 0;
    margin: 0;
    font-weight: lighter;
    text-align: center;
    font-family: 'Roboto', 'sans-serif';
    color: ${props => props.contrast === "" ? "#00bcd4" : "yellow"};
    text-decoration: ${props => props.contrast === "" ? "none" : "underline"};
    :hover{
      cursor: pointer;
      font-weight: 500;
    }
  }

  .active{
      background: ${props => props.contrast === "" ? "#e7e4e4" : "rgba(255,255,0,0.24)"};
      font-weight: 500;
    }
`

const Secao = styled.div`
  width: 90%; 
  margin: 0 auto;
  padding: 1em 0;
`
